==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property softDeleteTTL
 * @property subscriptionStateOverrideActions
 */
public data class ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
    public val softDeleteTTL: Output<String>? = null,
    public val subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder()
            .softDeleteTTL(softDeleteTTL?.applyValue({ args0 -> args0 }))
            .subscriptionStateOverrideActions(
                subscriptionStateOverrideActions?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs].
 */
@PulumiTagMarker
public class
ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgsBuilder
internal constructor() {
    private var softDeleteTTL: Output<String>? = null

    private var subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null

    /**
     * @param value
     */
    @JvmName("vyocaenlkjmhluka")
    public suspend fun softDeleteTTL(`value`: Output<String>) {
        this.softDeleteTTL = value
    }

    /**
     * @param value
     */
    @JvmName("bmtfbscqwbwskfxh")
    public suspend
    fun subscriptionStateOverrideActions(`value`: Output<List<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = value
    }

    @JvmName("gsegsihcayqhtdfr")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: Output<SubscriptionStateOverrideActionArgs>,
    ) {
        this.subscriptionStateOverrideActions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("rtibvtuideviigee")
    public suspend
    fun subscriptionStateOverrideActions(values: List<Output<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("yhmbqedyqdfyaigj")
    public suspend fun softDeleteTTL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.softDeleteTTL = mapped
    }

    /**
     * @param value
     */
    @JvmName("xkvmdhxivhqcucnd")
    public suspend
    fun subscriptionStateOverrideActions(`value`: List<SubscriptionStateOverrideActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("hdjmlltdonyvppew")
    public suspend
    fun subscriptionStateOverrideActions(argument: List<suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("vrsxwqprtdbcmtlp")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("nmionaxypciseiec")
    public suspend
    fun subscriptionStateOverrideActions(argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SubscriptionStateOverrideActionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param values
     */
    @JvmName("thprmqmoqbiscawy")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: SubscriptionStateOverrideActionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    internal fun build():
        ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
            softDeleteTTL = softDeleteTTL,
            subscriptionStateOverrideActions = subscriptionStateOverrideActions,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property softDeleteTTL
 * @property subscriptionStateOverrideActions
 */
public data class ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
    public val softDeleteTTL: Output<String>? = null,
    public val subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder()
            .softDeleteTTL(softDeleteTTL?.applyValue({ args0 -> args0 }))
            .subscriptionStateOverrideActions(
                subscriptionStateOverrideActions?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs].
 */
@PulumiTagMarker
public class
ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgsBuilder
internal constructor() {
    private var softDeleteTTL: Output<String>? = null

    private var subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null

    /**
     * @param value
     */
    @JvmName("xrfnajsncvydxoqw")
    public suspend fun softDeleteTTL(`value`: Output<String>) {
        this.softDeleteTTL = value
    }

    /**
     * @param value
     */
    @JvmName("ghaiqhgyukncinft")
    public suspend
    fun subscriptionStateOverrideActions(`value`: Output<List<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = value
    }

    @JvmName("axjvmjqiwesnwpid")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: Output<SubscriptionStateOverrideActionArgs>,
    ) {
        this.subscriptionStateOverrideActions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("vogtqbtiwmtwptif")
    public suspend
    fun subscriptionStateOverrideActions(values: List<Output<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ilhkgwuwhncsemnt")
    public suspend fun softDeleteTTL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.softDeleteTTL = mapped
    }

    /**
     * @param value
     */
    @JvmName("ngkeajtmtiipahca")
    public suspend
    fun subscriptionStateOverrideActions(`value`: List<SubscriptionStateOverrideActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("vhwrsowpcysihcpa")
    public suspend
    fun subscriptionStateOverrideActions(argument: List<suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qgmcqqcfjqlwsgdy")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("encodcpjwidwfdkk")
    public suspend
    fun subscriptionStateOverrideActions(argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SubscriptionStateOverrideActionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param values
     */
    @JvmName("lwoqwufuycnqhqmr")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: SubscriptionStateOverrideActionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    internal fun build():
        ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
            softDeleteTTL = softDeleteTTL,
            subscriptionStateOverrideActions = subscriptionStateOverrideActions,
        )
}
